@@ -24,10 +24,10 @@ _LOGGER = logging.getLogger(__name__)
 
 
 class Py2NDevice:
-    def __init__(self, aiohttp_session, connection_data: Py2NConnectionData):
+    def __init__(self, aiohttp_session, options: Py2NConnectionData):
         """Device init."""
         self.aiohttp_session: aiohttp.ClientSession = aiohttp_session
-        self.connection_data = connection_data
+        self.options = options
         self.data: Py2NDeviceData
         self.initialized: bool = False
 
